Bot class

Constructors

Bot({required String username, required String owner, String? webhookUrl, required String token, required int createdAt, required bool active, required List<String> permissions})
Bot.fromJson(Map<String, dynamic> json)
factory

Properties

active bool
final
createdAt int
final
hashCode int
The hash code for this object.
no setterinherited
owner String
final
permissions List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
username String
final
webhookUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited