ReplyMessage class

Constructors

ReplyMessage({required String id, required String from, required String text, required int ts, required bool hasFile, required bool hasVoice})
ReplyMessage.fromJson(Map<String, dynamic> json)
factory

Properties

from String
final
hasFile bool
final
hashCode int
The hash code for this object.
no setterinherited
hasVoice bool
final
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
ts int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited